==> pleiades_1.3.0-src.zip: src/jp/sourceforge/mergedoc/pleiades/aspect/resource/ExcludePackageProperties.java <==
/*
 * Copyright (c) 2005- Shinji Kashihara.
 * All rights reserved. This program are made available under
 * the terms of the Eclipse Public License v1.0 which accompanies
 * this distribution, and is available at epl-v10.html.
 */
package jp.sourceforge.mergedoc.pleiades.aspect.resource;

import java.io.File;
import java.io.FileNotFoundException;
import java.util.Arrays;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;

import jp.sourceforge.mergedoc.pleiades.log.Logger;
import jp.sourceforge.mergedoc.pleiades.resource.Files;
import jp.sourceforge.mergedoc.pleiades.resource.Property;
import jp.sourceforge.mergedoc.pleiades.resource.FileNames;
import jp.sourceforge.mergedoc.pleiades.resource.PropertySet;

/**
 * 翻訳除外パッケージ・プロパティーです。
 * <p>
 * @author cypher256
 */
public class ExcludePackageProperties implements FileNames {

	/** ロガー */
	private static final Logger log = Logger.getLogger(ExcludePackageProperties.class);

	/** このクラスのシングルトン・インスタンス */
	private static final ExcludePackageProperties singleton = new ExcludePackageProperties();

	/**
	 * 翻訳除外パッケージ・プロパティー・オブジェクトを取得します。
	 * <p>
	 * @return 翻訳除外パッケージ・プロパティー・オブジェクト
	 */
	public static ExcludePackageProperties getInstance() {
		return singleton;
	}

	/** 翻訳除外マップ */
	private final Map<String, Set<String>> map = new HashMap<String, Set<String>>();

	/**
	 * 翻訳除外パッケージ・プロパティーを構築します。
	 */
	private ExcludePackageProperties() {

		File file = Files.getResourceFile(TRANS_EXCLUDE_PACKAGE_PROP);
		if (!file.exists()) {
			String msg = file.getName() + " が見つかりません。";
			log.fatal(msg);
			Exception e = new FileNotFoundException(file.getPath());
			throw new IllegalStateException(msg, e);
		}

		PropertySet prop = new PropertySet(file);
		for (Property p : prop) {
			map.put(
				p.key,
				new HashSet<String>(Arrays.asList(p.value.split("\\s*,\\s*"))));
		}
	}

	/**
	 * 指定した英語リソース文字列から翻訳除外パス・エントリーを取得します。
	 * <p>
	 * @param enValue 英語リソース文字列
	 * @return 翻訳除外パス・エントリー。存在しない場合は null。
	 */
	public Set<String> getPathEntries(String enValue) {

		Set<String> pathEntries = map.get(enValue);
		if (pathEntries != null && pathEntries.contains("")) {
			log.info(new IllegalStateException(),
				"[" + enValue + "] の翻訳呼び出しスタックトレース。");
			return null;
		}
		return pathEntries;
	}
}

==> pleiades_1.3.2-src.zip: src/jp/sourceforge/mergedoc/pleiades/aspect/resource/ExcludePackageProperties.java <==
/*
 * Copyright (c) 2005- Shinji Kashihara.
 * All rights reserved. This program are made available under
 * the terms of the Eclipse Public License v1.0 which accompanies
 * this distribution, and is available at epl-v10.html.
 */
package jp.sourceforge.mergedoc.pleiades.aspect.resource;

import java.io.File;
import java.io.FileNotFoundException;
import java.util.Arrays;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;

import jp.sourceforge.mergedoc.pleiades.log.Logger;
import jp.sourceforge.mergedoc.pleiades.resource.Files;
import jp.sourceforge.mergedoc.pleiades.resource.Property;
import jp.sourceforge.mergedoc.pleiades.resource.FileNames;
import jp.sourceforge.mergedoc.pleiades.resource.PropertySet;

/**
 * 翻訳除外パッケージ・プロパティーです。
 * <p>
 * @author cypher256
 */
public class ExcludePackageProperties implements FileNames {

	/** ロガー */
	private static final Logger log = Logger.getLogger(ExcludePackageProperties.class);

	/** このクラスのシングルトン・インスタンス */
	private static final ExcludePackageProperties singleton = new ExcludePackageProperties();

	/**
	 * 翻訳除外パッケージ・プロパティー・オブジェクトを取得します。
	 * <p>
	 * @return 翻訳除外パッケージ・プロパティー・オブジェクト
	 */
	public static ExcludePackageProperties getInstance() {
		return singleton;
	}

	/** 翻訳除外マップ */
	private final Map<String, Set<String>> map = new HashMap<String, Set<String>>();

	/**
	 * 翻訳除外パッケージ・プロパティーを構築します。
	 */
	private ExcludePackageProperties() {

		File file = Files.getFile(TRANS_EXCLUDE_PACKAGE_PROP);
		if (!file.exists()) {
			String msg = file.getName() + " が見つかりません。";
			log.fatal(msg);
			Exception e = new FileNotFoundException(file.getPath());
			throw new IllegalStateException(msg, e);
		}

		PropertySet prop = new PropertySet(file);
		for (Property p : prop) {
			map.put(
				p.key,
				new HashSet<String>(Arrays.asList(p.value.split("\\s*,\\s*"))));
		}
	}

	/**
	 * 指定した英語リソース文字列から翻訳除外パス・エントリーを取得します。
	 * <p>
	 * @param enValue 英語リソース文字列
	 * @return 翻訳除外パス・エントリー。存在しない場合は null。
	 */
	public Set<String> getPathEntries(String enValue) {

		Set<String> pathEntries = map.get(enValue);
		if (pathEntries != null && pathEntries.contains("")) {
			log.info(new IllegalStateException(),
				"[" + enValue + "] の翻訳呼び出しスタックトレース。");
			return null;
		}
		return pathEntries;
	}
}
